@@ -3,10 +3,7 @@
 #' @description Takes a previously subsetted dataframe, clears its deleted levels and resets its row indexes.
 #' @param dataset Previously subsetted dataframe.
 #' @return Cleared dataframe.
-#' @export
 #' @keywords internal
-#' @examples
-#' clear_subset(iris[iris$Species == "setosa" & iris$Sepal.Length > 5 ,])
 clear_subset <- function(dataset){
   dataset <- droplevels(dataset)
   rownames(dataset) <- NULL
@@ -30,7 +27,6 @@ dec_1 <- function(x) sprintf("%.1f", x)
 #' @description Takes a numerical value and returns a print with 2 decimal figures.
 #' @param x Numerical value
 #' @return A character string with 2 decimal figures.
-#' @export
 #' @keywords internal
 dec_2 <- function(x) sprintf("%.2f", x)
 
@@ -48,6 +44,16 @@ dec_3 <- function(x) sprintf("%.3f", x)
 #' @keywords internal
 dec_4 <- function(x) sprintf("%.4f", x)
 
+#' Print a number with n decimal figures
+#' @description Takes a numerical value and returns a print with n decimal figures.
+#' @param x Numerical value
+#' @param n number of decimals
+#' @return A character string with 4 decimal figures.
+#' @keywords internal
+dec_n <- function(x,n){
+  sprintf(paste0("%.", n, "f"), x)
+}
+
 #' Verticalizes a dataframe
 #' @description Takes a dataframe with a set of different columns containing numerical values to be verticalized,
 #' returns a vertical dataframe with all variables in a single column called "VAR" together with a "VAR_TYPE" column
@@ -57,7 +63,6 @@ dec_4 <- function(x) sprintf("%.4f", x)
 #' @return A vertical dataframe containing the variables to be verticalized (column "VAR", numeric)
 #' and the name of the variable (column "VAR_TYPE", character strings).
 #' @keywords internal
-#' @export
 DF_verticalizer <- function(df_hor,      # horizontal dataframe
                             vert_col     # vector of column names of numerical variables to be verticalized
 ){
@@ -93,7 +98,6 @@ DF_verticalizer <- function(df_hor,      # horizontal dataframe
 #' @param layout user defined matrix layout (numeric matrix). default is NULL.
 #' @return A plot composed of multiple subplots.
 #' @keywords internal
-#' @export
 multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
   # Make a list from the ... arguments and plotlist
   plots <- c(list(...), plotlist)
@@ -147,19 +151,83 @@ calculation_gauge <- function(i, len){
 #' @param by_col Name of column from which NaN values should be removed. Character string.
 #' @param resetrows Logical value to reset the row numbering or not.
 #' @return Subset of dataframe without the rows containing NaN values in column by_col
-#' @export
 #' @keywords internal
-#' @examples
-#' ex_df <- data.frame(letters = c("A", "B", "C", "D"),  numbers = c(1,2,3,NaN))
-#' ex_df
-#' del_NaN_rows(ex_df, c("numbers"), TRUE)
 del_NaN_rows <- function(dataframe, by_col, resetrows){ # not used in app, could be unexported
   dataframe <- subset(dataframe,!(is.na(dataframe[by_col])))
   if(resetrows == TRUE){rownames(dataframe) <- NULL}
   return(dataframe)
 }
 
-#' Calculate delta values at t time with ODE solutions from \code{\link{ana_slvr}}
+#' edits a full dataframe of significance symbols from a dataframe of p-values
+#' @description edits a full dataframe of significance symbols from a dataframe of p-values
+#' \cr Symbols as asterisks denote p-values lower than .0001, .001, .01, .05. ns refers to non significant (higher than .5).
+#' @param x a data frame column of p-values or a pvalues as double (alone or in vector).
+#' @return p-values symbols as dataframe or as string.
+#' @keywords internal
+significance_pval_df <- function(x){
+  symbols <- c("****", "***", "**", "*", "ns")
+  cut_points <- c(0, 0.0001, 0.001, 0.01, 0.05, 1)
+  if(is.data.frame(x)) {
+    x_symbols <- x %>%
+      dplyr::mutate(dplyr::across(dplyr::everything(),
+                                  ~ symbols[base::findInterval(., cut_points)]))
+  }
+  if(is.double(x)) x_symbols <- symbols[findInterval(x, cut_points)]
+  return(x_symbols)
+}
+
+#' corr_stats
+#' @description edits dataframe report of linear regression and correlation tests (Pearson and Spearman)
+#' @param data_lm a data frame with X and Y data
+#' @param X name of X variable column (character)
+#' @param Y name of Y variable column (character)
+#' @param as_character reports statistics formatted as characters. Default is FALSE.
+#' @param n number of digits to display in correlation coefficient/rho. Default is 3. Only used if as_character = T.
+#' @param m number of digits to display in regression equation parameters (slope, y-intercept). Default is 4. Only used if as_character = T.
+#' @return report of regression and correlation tests
+#' @keywords internal
+corr_stats <- function (data_lm, X, Y, as_character = F,  n = 3, m = 4){
+  if(!is.data.frame(data_lm)) stop("data_lm should be a dataframe")
+  if(!is.logical(as_character)) stop("as_character should be a logical")
+  data_lm$X <- data_lm[, X]
+  data_lm$Y <- data_lm[, Y]
+  pearson_all <- stats::cor.test(data_lm$X, data_lm$Y, method = "pearson")
+  pearson_regeq <- base::summary(stats::lm(Y ~ X, data = data_lm))
+  spearman_all <- stats::cor.test(data_lm$X, data_lm$Y, method = "spearman", exact = F)
+  if (isTRUE(as_character)){
+    lm_df <- data.frame(X = X,
+                        Y = Y,
+                        n = base::nrow(data_lm),
+                        pear.R2 = dec_n(pearson_all$estimate^2, n),
+                        pear.pval = base::formatC(pearson_all$p.value, digits = 1, format = "e"),
+                        pear.signif = significance_pval_df(pearson_all$p.value),
+                        pear.yint = dec_n(pearson_regeq$coefficients[1,1], m),
+                        pear.yint.2se = dec_n(2*pearson_regeq$coefficients[1,2], m),
+                        pear.slope = dec_n(pearson_regeq$coefficients[2,1], m),
+                        pear.slope.2se = dec_n(2*pearson_regeq$coefficients[2,2], m),
+                        spear.Rho = dec_n(spearman_all$estimate, n),
+                        spear.pval = base::formatC(spearman_all$p.value, digits = 1, format = "e"),
+                        spear.signif = significance_pval_df(spearman_all$p.value))
+  } else {
+    lm_df <- data.frame(X = X,
+                        Y = Y,
+                        n = base::nrow(data_lm),
+                        pear.R2 = pearson_all$estimate^2,
+                        pear.pval = pearson_all$p.value,
+                        pear.signif = significance_pval_df(pearson_all$p.value),
+                        pear.yint = pearson_regeq$coefficients[1,1],
+                        pear.yint.2se = 2*pearson_regeq$coefficients[1,2],
+                        pear.slope = pearson_regeq$coefficients[2,1],
+                        pear.slope.2se = 2*pearson_regeq$coefficients[2,2],
+                        spear.Rho = spearman_all$estimate,
+                        spear.pval = spearman_all$p.value,
+                        spear.signif = significance_pval_df(spearman_all$p.value))
+  }
+
+  return(lm_df)
+}
+
+#' Calculate delta values at t time with ODE solutions from ana_slvr
 #' @description Calculate the delta values at t time using the ODE analytical solutions of the isotopic box model.
 #' @param t Time at which the delta values are to be calculated (numeric)
 #' @param ODE_Constants Constants as determined by the analytical solver for the system of \cr
@@ -169,11 +237,10 @@ del_NaN_rows <- function(dataframe, by_col, resetrows){ # not used in app, could
 #' @param ODE_Eigenvectors Eigenvectors as determined by the analytical solver for the system of \cr
 #' ordinary differential equations (multiple columns dataframe).
 #' @param BOXES_IDs Vector of character strings with the names of the boxes \cr
-#' in the same order as used in \code{\link{ana_slvr}}.
+#' in the same order as used in ana_slvr.
 #' @param ratio_standard Isotope ratio of the reference material used to calculate the delta values.
 #' @return Dataframe of the delta values in all boxes at t time.
 #' @keywords internal
-#' @seealso \code{\link{ana_slvr}}
 ANA_delta_t_Calculator <- function(t, ODE_Constants, ODE_Eigenvalues, ODE_Eigenvectors, BOXES_IDs, ratio_standard){
   R_t_loc <- ((ODE_Constants*exp(ODE_Eigenvalues*t)))%*%t(ODE_Eigenvectors)
   d_t_loc <- ((R_t_loc/ratio_standard)-1)*1000
@@ -198,39 +265,22 @@ ANA_delta_t_Calculator <- function(t, ODE_Constants, ODE_Eigenvalues, ODE_Eigenv
 #' \emph{micros, ms, s, min, h, d, wk, mo, yr, kyr, Myr, Gyr}
 #' @return a dataframe with values converted to new time unit.
 #' @keywords internal
-#' @export
-#' @examples
-#' ex_df <- data.frame(observation_num = c(1,2,3,4), time_d = c(100, 365, 1000, 3650))
-#' time_converter(ex_df, "time_d", "time_yr", "d", "yr")
 time_converter <- function(dataframe,
                            time_colname,
                            conv_timecolname,
                            former_unit, # "micros" "ms"     "s"      "min"    "h"      "d"      "wk"     "mo"     "yr"     "kyr"    "Myr"    "Gyr"
                            new_unit){   # "micros" "ms"     "s"      "min"    "h"      "d"      "wk"     "mo"     "yr"     "kyr"    "Myr"    "Gyr"
 
-  time_converting_table <- data.frame(UNIT = c("micros", "ms", "s", "min", "h", "d", "wk", "mo", "yr", "kyr", "Myr", "Gyr"),
-                                      micros = c(1, 0.001, 0.000001, 1.66666666666667E-08, 2.77777777777778E-10, 1.15740740740741E-11, 1.65343915343915E-12, 3.79477838506674E-13, 3.1688087804657E-14, 3.1688087804657E-17, 3.1688087804657E-20, 3.1688087804657E-23),
-                                      ms = c(1000, 1, 0.000001, 1.66666666666667E-08, 2.77777777777778E-10, 1.15740740740741E-11, 1.65343915343915E-12, 3.79477838506674E-13, 3.1688087804657E-14, 3.1688087804657E-17, 3.1688087804657E-20, 3.1688087804657E-23),
-                                      s = c(1000000, 1000000, 1, 0.0166666666666667, 0.000277777777777778, 1.15740740740741E-05, 1.65343915343915E-06, 3.79477838506674E-07, 3.1688087804657E-08, 3.1688087804657E-11, 3.1688087804657E-14, 3.1688087804657E-17),
-                                      min = c(60000000, 60000000, 60, 1, 0.0166666666666667, 0.000694444444444444, 9.92063492063492E-05, 2.27686703104004E-05, 1.90128526827942E-06, 1.90128526827942E-09, 1.90128526827942E-12, 1.90128526827942E-15),
-                                      h = c(3600000000, 3600000000, 3600, 60, 1, 0.0416666666666667, 0.00595238095238095, 0.00136612021862403, 0.000114077116096765, 1.14077116096765E-07, 1.14077116096765E-10, 1.14077116096765E-13),
-                                      d = c(86400000000, 86400000000, 86400, 1440, 24, 1, 0.142857142857143, 0.0327868852469766, 0.00273785078632237, 2.73785078632237E-06, 2.73785078632237E-09, 2.73785078632237E-12),
-                                      wk = c(604800000000, 604800000000, 604800, 10080, 168, 7, 1, 0.229508196728836, 0.0191649555042566, 1.91649555042566E-05, 1.91649555042566E-08, 1.91649555042566E-11),
-                                      mo = c(2635199999913.6, 2635199999913.6, 2635199.9999136, 43919.99999856, 731.999999976, 30.499999999, 4.357142857, 1, 0.0835044489800944, 8.35044489800944E-05, 8.35044489800944E-08, 8.35044489800944E-11),
-                                        yr = c(31557600009333.3, 31557600009333.3, 31557600.0093333, 525960.000155555, 8766.00000259259, 365.250000108025, 52.1785714440035, 11.97540984, 1, 0.001, 0.000001, 0.000000001),
-                                      kyr = c(31557600009333300, 31557600009333300, 31557600009.3333, 525960000.155555, 8766000.00259259, 365250.000108025, 52178.5714440035, 11975.40984, 1000, 1, 0.001, 0.000001),
-                                      Myr = c(31557600009333300000, 31557600009333300000, 31557600009333.3, 525960000155.555, 8766000002.59259, 365250000.108025, 52178571.4440035, 11975409.84, 1000000, 1000, 1, 0.001),
-                                      Gyr = c(3.15576000093333E+22, 3.15576000093333E+22, 31557600009333300, 525960000155555, 8766000002592.59, 365250000108.025, 52178571444.0035, 11975409840, 1000000000, 1000000, 1000, 1))
-
-  if (!(former_unit %in% time_converting_table$UNIT)){
-    rlang::abort(paste("Native time unit should be among the following: ", paste(time_converting_table$UNIT, collapse = ", ")))
+  # time_conversions from sysdata.rda
+  if (!(former_unit %in% time_conversions$UNIT)){
+    rlang::abort(paste("Native time unit should be among the following: ", paste(time_conversions$UNIT, collapse = ", ")))
   }
 
-  if (!(new_unit %in% time_converting_table$UNIT)){
-    rlang::abort(paste("Conversion time unit should be among the following: ", paste(time_converting_table$UNIT, collapse = ", ")))
+  if (!(new_unit %in% time_conversions$UNIT)){
+    rlang::abort(paste("Conversion time unit should be among the following: ", paste(time_conversions$UNIT, collapse = ", ")))
   }
 
-  dataframe$conv_timecolname <- dataframe[,time_colname]*time_converting_table[time_converting_table$UNIT == new_unit, former_unit]
+  dataframe$conv_timecolname <- dataframe[,time_colname]*time_conversions[time_conversions$UNIT == new_unit, former_unit]
   names(dataframe)[names(dataframe) == "conv_timecolname"] <- conv_timecolname
   return(dataframe)
 }
@@ -292,11 +342,11 @@ plot_diagram <- function(input, title, matrix_layout, BOXES_master_loc, COEFF_FL
                  vsize = 14*exp(-nrow(BOXES_master_loc)/80)+1)
 }
 
-#' using_extdata_tutorial
-#' @description identifies workdir value refering to use of extdata tutorial files, returns correct workdir value, \cr
+#' using_extdata_tutorial V1
+#' @description identifies workdir value referring to use of extdata tutorial files, returns correct workdir value, \cr
 #' prevents saving outputs locally (save_run_outputs = FALSE) \cr
 #' forces display of default graphical output to R session (plot_results = TRUE)
-#' @param workdir working directory value refering to extdata tutorial files, several options among the following: \cr
+#' @param workdir working directory value referring to extdata tutorial files, several options among the following: \cr
 #' c("/Users/username/Documents/1_ABC_tutorial",
 #' "use_isobxr_demonstration_files",
 #' system.file("extdata", package = "isobxr"),
@@ -321,3 +371,48 @@ using_extdata_tutorial <- function(workdir, save_run_outputs, plot_results){
   }
   return(c(tuto_mode, workdir, save_run_outputs, plot_results))
 }
+
+#' using_extdata_tutorial_2
+#' @description identifies workdir value referring to use of extdata tutorial files, returns correct workdir value, \cr
+#' prevents saving outputs locally (save_run_outputs = FALSE) \cr
+#' forces display of default graphical output to R session (plot_results = TRUE)
+#' @param workdir working directory value referring to extdata tutorial files, several options among the following: \cr
+#' c("/Users/username/Documents/1_ABC_tutorial",
+#' "use_isobxr_demonstration_files",
+#' system.file("extdata", package = "isobxr"),
+#' system.file("extdata", "0_ISOBXR_MASTER.xlsx", package = "isobxr"))
+#' @return a list with a boolean stating whether this is a tutorial mode, a workdir value allowing reading of extdata tutorial files, save_run_outputs = FALSE, plot_results = TRUE
+#' @keywords internal
+using_extdata_tutorial_2 <- function(workdir, save_outputs, plot_results){
+
+  workdir_to_extdata <- c("/Users/username/Documents/1_ABC_tutorial",
+                          "use_isobxr_demonstration_files",
+                          "demo",
+                          system.file("extdata", package = "isobxr"),
+                          system.file("extdata", "0_ISOBXR_MASTER.xlsx", package = "isobxr"))
+
+  if (workdir %in% workdir_to_extdata){
+    workdir <- system.file("extdata", package = "isobxr")
+    save_outputs = FALSE
+    plot_results = TRUE
+    tuto_mode = TRUE
+    # rlang::inform("You are using the external data embedded in the isobxr package for the tutorial.
+    # This will allow you to run the demonstration models but won't allow to save the outputs to your local working directory.
+    # In order to be able to do so, download and save the tutorial files to your working directory.")
+  } else {
+    tuto_mode = FALSE
+  }
+
+  return(list(tuto_mode = tuto_mode,
+              workdir = workdir,
+              save_outputs = save_outputs,
+              plot_results = plot_results))
+}
+
+#' tempdir_tree
+#' @description display tree of the temporary isobxr directory
+#' @return a print of the directory tree
+#' @keywords internal
+tempdir_tree <- function(){
+  fs::dir_tree(paste0(tempdir(""), "/isobxr_temp_data"))
+}
